@@ -3,7 +3,9 @@ package cli
 import (
 	"fmt"
 	"runtime"
+	"slices"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/engine"
 	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/upgrade"
 	"github.com/spf13/cobra"
@@ -18,7 +20,13 @@ var upgradeCmd = &cobra.Command{
 	Long:  "Upgrade when a new version is available.",
 	Args:  cobra.NoArgs,
 	Run: func(_ *cobra.Command, _ []string) {
-		if runtime.GOOS == platform.LINUX {
+		supportedPlatforms := []string{
+			platform.WINDOWS,
+			platform.DARWIN,
+			platform.LINUX,
+		}
+
+		if !slices.Contains(supportedPlatforms, runtime.GOOS) {
 			fmt.Print("\n⚠️ upgrade is not supported on this platform\n\n")
 			return
 		}
@@ -34,8 +42,12 @@ var upgradeCmd = &cobra.Command{
 			return
 		}
 
+		cfg := engine.LoadConfig(env)
+
 		if _, hasNotice := upgrade.Notice(env, true); !hasNotice {
-			fmt.Print("\n✅  no new version available\n\n")
+			if !cfg.DisableNotice {
+				fmt.Print("\n✅  no new version available\n\n")
+			}
 			return
 		}
 
