@@ -7,16 +7,7 @@ if '::UPGRADE::' == 'true' then
 end
 
 -- Cache PID
-
-function generateCustomUUID()
-    local template = 'xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx'
-    return string.gsub(template, '[x]', function(c)
-        local v = math.random(0, 0xf)
-        return string.format('%x', v)
-    end)
-end
-
-os.setenv("POSH_PID", generateCustomUUID())
+os.setenv("POSH_PID", os.getpid())
 
 -- Helper functions
 
@@ -335,3 +326,8 @@ end
 if tooltips_enabled and rl.setbinding then
     rl.setbinding(' ', [["luafunc:ohmyposh_space"]], 'emacs')
 end
+
+if '::AUTOUPGRADE::' == 'true' then
+    local prompt_exe = string.format('%s upgrade', omp_exe())
+    os.execute(prompt_exe)
+end
