@@ -30,17 +30,15 @@ type release struct {
 }
 
 const (
-	RELEASEURL    = "https://api.github.com/repos/jandedobbeleer/oh-my-posh/releases/latest"
+	RELEASEURL = "https://api.github.com/repos/jandedobbeleer/oh-my-posh/releases/latest"
+	CACHEKEY   = "upgrade_check"
+
 	upgradeNotice = `
 A new release of Oh My Posh is available: %s → %s
-%s
-`
-	windows = `To upgrade, use the guide for your favorite package manager in the documentation:
-https://ohmyposh.dev/docs/installation/windows#update`
-	unix   = "To upgrade, use your favorite package manager or, if you used Homebrew to install, run: 'brew update; brew upgrade oh-my-posh'"
-	darwin = "To upgrade, run: 'brew update; brew upgrade oh-my-posh'"
+To upgrade, run: 'oh-my-posh upgrade'
 
-	CACHEKEY = "upgrade_check"
+To enable automated upgrades, set 'auto_upgrade' to 'true' in your configuration.
+`
 )
 
 func Latest(env platform.Environment) (string, error) {
@@ -82,15 +80,5 @@ func Notice(env platform.Environment, force bool) (string, bool) {
 		return "", false
 	}
 
-	var notice string
-	switch env.GOOS() {
-	case platform.WINDOWS:
-		notice = windows
-	case platform.DARWIN:
-		notice = darwin
-	case platform.LINUX:
-		notice = unix
-	}
-
-	return fmt.Sprintf(upgradeNotice, version, latest, notice), true
+	return fmt.Sprintf(upgradeNotice, version, latest), true
 }
